---
coding: utf-8

title: A Uniform Resource Name (URN) Namespace for data sets (DATA)
abbrev: URN DATA namespace for data sets
docname: draft-rocha-urn-data-00
category: info
date: 2021-04-22
# date: 2012-01
# date: 2012

stand_alone: yes

ipr: trust200902
# area: Applications
# wg: CoRE Working Group
# kw: Internet-Draft

pi:
  toc: yes
  sortrefs:   # defaults to yes
  symrefs: yes
  # comments: yes

author:
      -
        ins: E. Rocha
        name: Emerson Rocha
        org: Etica.AI
        country: Brazil
        email: rocha@ieee.org

normative:
  RFC8141:
  RFC2119:
# #        - rfc2119
# #        - rfc2616
# #        - I-D.ietf-core-coap
#   RFC2119:
#   RFC2616:
#   I-D.ietf-core-coap:

# informative:
#   REST:
#     title: Architectural Styles and the Design of Network-based Software Architectures
#     author:
# #      -
#         ins: R. Fielding
#         name: Roy Fielding
#         org: University of California, Irvine
#     date: 2000

# entity:
#         SELF: "[RFCXXXX]"
--- abstract

insert abstract here

--- middle

# Introduction

## The Purpose of Namespace "data"

## Terminology

The key words "MUST", "MUST NOT", "REQUIRED", "SHALL", "SHALL NOT",
"SHOULD", "SHOULD NOT", "RECOMMENDED", "MAY", and "OPTIONAL" in this
document are to be interpreted as described in [RFC2119].

# Registration Template

Namespace Identifier:

(DRAFT!) "data" requested according to [RFC8141]. (DRAFT!)

Version:

1.0

Date:

YYYY-MM-DD

Registrant:

(TODO)

Purpose:

(TODO)

Syntax:

(TODO)

Assignment:

(TODO)

Security and Privacy:

(TODO)

Interoperability:

(TODO)

Resolution:

(TODO)

Documentation:

(TODO)

Additional Information:

(TODO)

Revision Information:

None

# Principles of the Resolution Service

## (TEMP)


```bash
# http://urn.arpa/urn:data:xz:hxl:standard:core:hashtag
# http://data.urn.arpa/urn:data:xz:hxl:standard:core:hashtag

urnresolver --all urn:data:xz:hxl:standard:core:hashtag


```

# IANA Considerations
